@@ -7,18 +7,28 @@ utils::globalVariables(
     read.table(ufile, header = TRUE)
 }
 
-repo_short_names <- data.frame(
-  repository =
-    c("software", "data-experiment", "workflows", "data-annotation", "books"),
-  stat.url =
-    c("bioc", "data-experiment", "workflows", "data-annotation", NA_character_),
-  stat.file =
-    c("bioc", "experiment", "workflows", "annotation", NA_character_),
-  json.file =
-    c("bioc", "data/experiment", "workflows", "data/annotation", NA_character_),
-  repo.name =
-    c("BioCsoft", "BioCexp", "BioCworkflows", "BioCann", "BioCbooks")
-)
+.repos_short_names <- function() {
+    data.frame(
+        code.names = c(
+            "software", "data-experiment", "workflows", "data-annotation",
+            "books"
+        ),
+        stat.url = c(
+            "bioc", "data-experiment", "workflows", "data-annotation",
+            NA_character_
+        ),
+        stat.file = c(
+            "bioc", "experiment", "workflows", "annotation", NA_character_
+        ),
+        pkg.url = c(
+            "bioc", "data/experiment", "workflows", "data/annotation",
+            NA_character_
+        ),
+        biocmanager.names = c(
+            "BioCsoft", "BioCexp", "BioCworkflows", "BioCann", "BioCbooks"
+        )
+    )
+}
 
 .get_all_biocpkgs <- function() {
     db <- available.packages(
@@ -27,22 +37,27 @@ repo_short_names <- data.frame(
     rownames(db)
 }
 
+#' @importFrom httr2 request req_options req_perform
 .filter_http_error <- function(urls) {
-    invalid <- vapply(
-        urls,
-        httr::http_error,
-        logical(1L),
-        httr::config(followlocation = 0L)
-    )
-    if (any(invalid)) {
-        inv_urls <- paste(names(urls)[invalid], collapse = ", ")
+    check_url <- function(url) {
+        res <- try({
+            request(url) |>
+                req_options(followlocation = FALSE) |>
+                req_perform()
+        }, silent = TRUE)
+        !inherits(res, "try-error")
+    }
+    is_valid <- vapply(urls, check_url, logical(1L))
+
+    if (any(!is_valid)) {
+        inv_urls <- paste(names(urls)[!is_valid], collapse = ", ")
         warning(
-            "Download stats for these resources are currently down:\n  ",
+            "Download stats for these resources are currently down:\n ",
             inv_urls,
             call. = FALSE
         )
     }
-    urls[!invalid]
+    urls[is_valid]
 }
 
 .STATS_BASE_URL <- "https://bioconductor.org/packages/stats/"
@@ -52,8 +67,9 @@ repo_short_names <- data.frame(
 #' @details Note that Bioconductor package download
 #' stats are not version-specific.
 #'
-#' @param pkgType character(1) All or one of 'software', 'data-experiment',
-#'     'workflows', or 'data-annotation' (defaults to all types)
+#' @param pkgType character() All, some, or one of 'software',
+#'   'data-experiment', 'workflows', or 'data-annotation' (defaults to all
+#'   types)
 #'
 #' @importFrom dplyr mutate
 #' @importFrom utils read.table
@@ -75,16 +91,14 @@ biocDownloadStats <-
         )
     )
 {
-    if (identical(pkgType, "all")) {
-        .Deprecated(
-            msg = "Value 'all' is deprecated for 'pkgType' argument"
+    if (identical(pkgType, "all"))
+        .Defunct(
+            msg = "Value 'all' is defunct as 'pkgType' option"
         )
-        pkgType <- eval(formals()[["pkgType"]])
-    }
     pkgType <- match.arg(pkgType, several.ok = TRUE)
     linkPkg <- .matchGetShortName(pkgType, "stat.url")
     fnameType <- .matchGetShortName(pkgType, "stat.file")
-    repo_name <- .matchGetShortName(pkgType, "repo.name")
+    repo_name <- .matchGetShortName(pkgType, "biocmanager.names")
     pkgs <- biocPkgList(repo = repo_name)[["Package"]]
 
     base_url <- paste0(.STATS_BASE_URL, "%s/%s_pkg_stats.tab")
@@ -209,7 +223,8 @@ firstInBioc <- function(download_stats) {
 }
 
 .matchGetShortName <- function(pkgType, colName) {
-    repo_short_names[match(pkgType, repo_short_names[["repository"]]), colName]
+    rsn <- .repos_short_names()
+    rsn[match(pkgType, rsn[["code.names"]]), colName]
 }
 
 #' What is a package's download rank?
@@ -240,7 +255,7 @@ pkgDownloadRank <-
     )
 {
     pkgType <- match.arg(pkgType)
-    jsonPath <- .matchGetShortName(pkgType, "json.file")
+    jsonPath <- .matchGetShortName(pkgType, "pkg.url")
     rankURL <-
         "https://www.bioconductor.org/packages/json/%s/%s/packages.json"
     ufile <- .cache_url_file(sprintf(rankURL, version, jsonPath))
@@ -248,7 +263,7 @@ pkgDownloadRank <-
     pkgs <- jsonlite::fromJSON(ufile)
     rank <- pkgs[[pkg]]$Rank
 
-    repoType <- .matchGetShortName(pkgType, "repo.name")
+    repoType <- .matchGetShortName(pkgType, "biocmanager.names")
     viewsdb <- get_VIEWS(version = version, repoType)
 
     pct <- round(rank*100 / nrow(viewsdb), 2)
