@@ -129,15 +129,15 @@ biocPkgList <- function(
                       ret$biocViews = tmp
                     }
 
-                    ret[["Author"]] = ret[["Author"]] %>%
-                        str_replace_all("\n", " ") %>%
-                        str_remove_all("\\[.*?\\]") %>%
-                        str_remove_all("<.*?>") %>%
-                        str_remove_all("\\(.*?\\)") %>%
-                        str_squish() %>%
-                        str_replace_all("\\w* contributions ?\\w*", ", ") %>%
-                        str_replace_all("\\sand\\s", ", ") %>%
-                        str_replace_all(",\\s+,", ",") %>%
+                    ret[["Author"]] = ret[["Author"]] |>
+                        str_replace_all("\n", " ") |>
+                        str_remove_all("\\[.*?\\]") |>
+                        str_remove_all("<.*?>") |>
+                        str_remove_all("\\(.*?\\)") |>
+                        str_squish() |>
+                        str_replace_all("\\w* contributions ?\\w*", ", ") |>
+                        str_replace_all("\\sand\\s", ", ") |>
+                        str_replace_all(",\\s+,", ",") |>
                         str_replace_all(",+", ",")
 
                     ret[["Author"]] = lapply(
@@ -189,10 +189,7 @@ get_VIEWS <- function(version, type) {
 }
 
 CRAN_pkg_rds_url <- function() {
-    cran_repo <- BiocManager:::.repositories_base()
-    if (any(grepl("packagemanager", cran_repo["CRAN"])))
-        cran_repo <- .CRAN_WEB_URL
-    paste0(cran_repo, "/web/packages/packages.rds")
+    paste0(.CRAN_WEB_URL, "/web/packages/packages.rds")
 }
 
 read_CRAN_url <- function(url) {
