@@ -29,14 +29,9 @@ biocPkgRanges <-
 {
     condition <- match.arg(condition)
     version <- match.arg(version)
-    version <- BiocManager:::.version_bioc(version)
 
-    build_status_db <- get_build_status_db_url(version)
-    status_file <- .cache_url_file(build_status_db)
-    dat <- readLines(status_file)
-    sdat <- strsplit(dat, "#")
-    sdat <- data.frame(do.call(rbind, sdat), row.names=NULL)
-    names(sdat) <- c("package", "host", "status")
+    sdat <- biocBuildStatusDB(version = version, pkgType = "software")
+
     cur <- which(sdat$package >= start & sdat$package <= end)
     if (!length(cur))
         stop("no packages in range")
